@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
 
@@ -36,9 +34,8 @@ class FixedOrPercent(proto.Message):
             reference value.
     """
 
-    fixed = proto.Field(proto.INT32, number=1, oneof="mode")
-
-    percent = proto.Field(proto.INT32, number=2, oneof="mode")
+    fixed = proto.Field(proto.INT32, number=1, oneof="mode",)
+    percent = proto.Field(proto.INT32, number=2, oneof="mode",)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
