@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,13 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.osconfig_v1.types import osconfig_common
-from google.protobuf import duration_pb2 as gp_duration  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -62,15 +59,15 @@ class ExecutePatchJobRequest(proto.Message):
         description (str):
             Description of the patch job. Length of the
             description is limited to 1024 characters.
-        instance_filter (~.gco_patch_jobs.PatchInstanceFilter):
+        instance_filter (google.cloud.osconfig_v1.types.PatchInstanceFilter):
             Required. Instances to patch, either
             explicitly or filtered by some criteria such as
             zone or labels.
-        patch_config (~.gco_patch_jobs.PatchConfig):
+        patch_config (google.cloud.osconfig_v1.types.PatchConfig):
             Patch configuration being applied. If
             omitted, instances are patched using the default
             configurations.
-        duration (~.gp_duration.Duration):
+        duration (google.protobuf.duration_pb2.Duration):
             Duration of the patch job. After the duration
             ends, the patch job times out.
         dry_run (bool):
@@ -79,39 +76,31 @@ class ExecutePatchJobRequest(proto.Message):
         display_name (str):
             Display name for this patch job. This does
             not have to be unique.
-        rollout (~.gco_patch_jobs.PatchRollout):
+        rollout (google.cloud.osconfig_v1.types.PatchRollout):
             Rollout strategy of the patch job.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    description = proto.Field(proto.STRING, number=2)
-
+    parent = proto.Field(proto.STRING, number=1,)
+    description = proto.Field(proto.STRING, number=2,)
     instance_filter = proto.Field(
         proto.MESSAGE, number=7, message="PatchInstanceFilter",
     )
-
     patch_config = proto.Field(proto.MESSAGE, number=4, message="PatchConfig",)
-
-    duration = proto.Field(proto.MESSAGE, number=5, message=gp_duration.Duration,)
-
-    dry_run = proto.Field(proto.BOOL, number=6)
-
-    display_name = proto.Field(proto.STRING, number=8)
-
+    duration = proto.Field(proto.MESSAGE, number=5, message=duration_pb2.Duration,)
+    dry_run = proto.Field(proto.BOOL, number=6,)
+    display_name = proto.Field(proto.STRING, number=8,)
     rollout = proto.Field(proto.MESSAGE, number=9, message="PatchRollout",)
 
 
 class GetPatchJobRequest(proto.Message):
     r"""Request to get an active or completed patch job.
-
     Attributes:
         name (str):
             Required. Name of the patch in the form
             ``projects/*/patchJobs/*``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ListPatchJobInstanceDetailsRequest(proto.Message):
@@ -135,13 +124,10 @@ class ListPatchJobInstanceDetailsRequest(proto.Message):
             zone, name, state, or ``failure_reason``.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
-
-    filter = proto.Field(proto.STRING, number=4)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
+    filter = proto.Field(proto.STRING, number=4,)
 
 
 class ListPatchJobInstanceDetailsResponse(proto.Message):
@@ -149,7 +135,7 @@ class ListPatchJobInstanceDetailsResponse(proto.Message):
     patch job.
 
     Attributes:
-        patch_job_instance_details (Sequence[~.gco_patch_jobs.PatchJobInstanceDetails]):
+        patch_job_instance_details (Sequence[google.cloud.osconfig_v1.types.PatchJobInstanceDetails]):
             A list of instance status.
         next_page_token (str):
             A pagination token that can be used to get
@@ -163,8 +149,7 @@ class ListPatchJobInstanceDetailsResponse(proto.Message):
     patch_job_instance_details = proto.RepeatedField(
         proto.MESSAGE, number=1, message="PatchJobInstanceDetails",
     )
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class PatchJobInstanceDetails(proto.Message):
@@ -180,7 +165,7 @@ class PatchJobInstanceDetails(proto.Message):
         instance_system_id (str):
             The unique identifier for the instance. This
             identifier is defined by the server.
-        state (~.gco_patch_jobs.Instance.PatchState):
+        state (google.cloud.osconfig_v1.types.Instance.PatchState):
             Current state of instance patch.
         failure_reason (str):
             If the patch fails, this field provides the
@@ -190,20 +175,15 @@ class PatchJobInstanceDetails(proto.Message):
             attempts to apply the patch.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    instance_system_id = proto.Field(proto.STRING, number=2)
-
+    name = proto.Field(proto.STRING, number=1,)
+    instance_system_id = proto.Field(proto.STRING, number=2,)
     state = proto.Field(proto.ENUM, number=3, enum="Instance.PatchState",)
-
-    failure_reason = proto.Field(proto.STRING, number=4)
-
-    attempt_count = proto.Field(proto.INT64, number=5)
+    failure_reason = proto.Field(proto.STRING, number=4,)
+    attempt_count = proto.Field(proto.INT64, number=5,)
 
 
 class ListPatchJobsRequest(proto.Message):
     r"""A request message for listing patch jobs.
-
     Attributes:
         parent (str):
             Required. In the form of ``projects/*``
@@ -220,20 +200,16 @@ class ListPatchJobsRequest(proto.Message):
             filtering is only available on the patch_deployment field.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
-
-    filter = proto.Field(proto.STRING, number=4)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
+    filter = proto.Field(proto.STRING, number=4,)
 
 
 class ListPatchJobsResponse(proto.Message):
     r"""A response message for listing patch jobs.
-
     Attributes:
-        patch_jobs (Sequence[~.gco_patch_jobs.PatchJob]):
+        patch_jobs (Sequence[google.cloud.osconfig_v1.types.PatchJob]):
             The list of patch jobs.
         next_page_token (str):
             A pagination token that can be used to get
@@ -245,8 +221,7 @@ class ListPatchJobsResponse(proto.Message):
         return self
 
     patch_jobs = proto.RepeatedField(proto.MESSAGE, number=1, message="PatchJob",)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class PatchJob(proto.Message):
@@ -269,20 +244,20 @@ class PatchJob(proto.Message):
         description (str):
             Description of the patch job. Length of the
             description is limited to 1024 characters.
-        create_time (~.timestamp.Timestamp):
+        create_time (google.protobuf.timestamp_pb2.Timestamp):
             Time this patch job was created.
-        update_time (~.timestamp.Timestamp):
+        update_time (google.protobuf.timestamp_pb2.Timestamp):
             Last time this patch job was updated.
-        state (~.gco_patch_jobs.PatchJob.State):
+        state (google.cloud.osconfig_v1.types.PatchJob.State):
             The current state of the PatchJob.
-        instance_filter (~.gco_patch_jobs.PatchInstanceFilter):
+        instance_filter (google.cloud.osconfig_v1.types.PatchInstanceFilter):
             Instances to patch.
-        patch_config (~.gco_patch_jobs.PatchConfig):
+        patch_config (google.cloud.osconfig_v1.types.PatchConfig):
             Patch configuration being applied.
-        duration (~.gp_duration.Duration):
+        duration (google.protobuf.duration_pb2.Duration):
             Duration of the patch job. After the duration
             ends, the patch job times out.
-        instance_details_summary (~.gco_patch_jobs.PatchJob.InstanceDetailsSummary):
+        instance_details_summary (google.cloud.osconfig_v1.types.PatchJob.InstanceDetailsSummary):
             Summary of instance details.
         dry_run (bool):
             If this patch job is a dry run, the agent
@@ -298,7 +273,7 @@ class PatchJob(proto.Message):
         patch_deployment (str):
             Output only. Name of the patch deployment
             that created this patch job.
-        rollout (~.gco_patch_jobs.PatchRollout):
+        rollout (google.cloud.osconfig_v1.types.PatchRollout):
             Rollout strategy being applied.
     """
 
@@ -364,68 +339,40 @@ class PatchJob(proto.Message):
                 communicate with the service.
         """
 
-        pending_instance_count = proto.Field(proto.INT64, number=1)
-
-        inactive_instance_count = proto.Field(proto.INT64, number=2)
-
-        notified_instance_count = proto.Field(proto.INT64, number=3)
-
-        started_instance_count = proto.Field(proto.INT64, number=4)
-
-        downloading_patches_instance_count = proto.Field(proto.INT64, number=5)
-
-        applying_patches_instance_count = proto.Field(proto.INT64, number=6)
-
-        rebooting_instance_count = proto.Field(proto.INT64, number=7)
-
-        succeeded_instance_count = proto.Field(proto.INT64, number=8)
-
-        succeeded_reboot_required_instance_count = proto.Field(proto.INT64, number=9)
-
-        failed_instance_count = proto.Field(proto.INT64, number=10)
-
-        acked_instance_count = proto.Field(proto.INT64, number=11)
-
-        timed_out_instance_count = proto.Field(proto.INT64, number=12)
-
-        pre_patch_step_instance_count = proto.Field(proto.INT64, number=13)
-
-        post_patch_step_instance_count = proto.Field(proto.INT64, number=14)
-
-        no_agent_detected_instance_count = proto.Field(proto.INT64, number=15)
-
-    name = proto.Field(proto.STRING, number=1)
-
-    display_name = proto.Field(proto.STRING, number=14)
-
-    description = proto.Field(proto.STRING, number=2)
-
-    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
-
-    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp.Timestamp,)
+        pending_instance_count = proto.Field(proto.INT64, number=1,)
+        inactive_instance_count = proto.Field(proto.INT64, number=2,)
+        notified_instance_count = proto.Field(proto.INT64, number=3,)
+        started_instance_count = proto.Field(proto.INT64, number=4,)
+        downloading_patches_instance_count = proto.Field(proto.INT64, number=5,)
+        applying_patches_instance_count = proto.Field(proto.INT64, number=6,)
+        rebooting_instance_count = proto.Field(proto.INT64, number=7,)
+        succeeded_instance_count = proto.Field(proto.INT64, number=8,)
+        succeeded_reboot_required_instance_count = proto.Field(proto.INT64, number=9,)
+        failed_instance_count = proto.Field(proto.INT64, number=10,)
+        acked_instance_count = proto.Field(proto.INT64, number=11,)
+        timed_out_instance_count = proto.Field(proto.INT64, number=12,)
+        pre_patch_step_instance_count = proto.Field(proto.INT64, number=13,)
+        post_patch_step_instance_count = proto.Field(proto.INT64, number=14,)
+        no_agent_detected_instance_count = proto.Field(proto.INT64, number=15,)
 
+    name = proto.Field(proto.STRING, number=1,)
+    display_name = proto.Field(proto.STRING, number=14,)
+    description = proto.Field(proto.STRING, number=2,)
+    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
     state = proto.Field(proto.ENUM, number=5, enum=State,)
-
     instance_filter = proto.Field(
         proto.MESSAGE, number=13, message="PatchInstanceFilter",
     )
-
     patch_config = proto.Field(proto.MESSAGE, number=7, message="PatchConfig",)
-
-    duration = proto.Field(proto.MESSAGE, number=8, message=gp_duration.Duration,)
-
+    duration = proto.Field(proto.MESSAGE, number=8, message=duration_pb2.Duration,)
     instance_details_summary = proto.Field(
         proto.MESSAGE, number=9, message=InstanceDetailsSummary,
     )
-
-    dry_run = proto.Field(proto.BOOL, number=10)
-
-    error_message = proto.Field(proto.STRING, number=11)
-
-    percent_complete = proto.Field(proto.DOUBLE, number=12)
-
-    patch_deployment = proto.Field(proto.STRING, number=15)
-
+    dry_run = proto.Field(proto.BOOL, number=10,)
+    error_message = proto.Field(proto.STRING, number=11,)
+    percent_complete = proto.Field(proto.DOUBLE, number=12,)
+    patch_deployment = proto.Field(proto.STRING, number=15,)
     rollout = proto.Field(proto.MESSAGE, number=16, message="PatchRollout",)
 
 
@@ -434,26 +381,26 @@ class PatchConfig(proto.Message):
     to apply the patch(es) to a VM instance.
 
     Attributes:
-        reboot_config (~.gco_patch_jobs.PatchConfig.RebootConfig):
+        reboot_config (google.cloud.osconfig_v1.types.PatchConfig.RebootConfig):
             Post-patch reboot settings.
-        apt (~.gco_patch_jobs.AptSettings):
+        apt (google.cloud.osconfig_v1.types.AptSettings):
             Apt update settings. Use this setting to override the
             default ``apt`` patch rules.
-        yum (~.gco_patch_jobs.YumSettings):
+        yum (google.cloud.osconfig_v1.types.YumSettings):
             Yum update settings. Use this setting to override the
             default ``yum`` patch rules.
-        goo (~.gco_patch_jobs.GooSettings):
+        goo (google.cloud.osconfig_v1.types.GooSettings):
             Goo update settings. Use this setting to override the
             default ``goo`` patch rules.
-        zypper (~.gco_patch_jobs.ZypperSettings):
+        zypper (google.cloud.osconfig_v1.types.ZypperSettings):
             Zypper update settings. Use this setting to override the
             default ``zypper`` patch rules.
-        windows_update (~.gco_patch_jobs.WindowsUpdateSettings):
+        windows_update (google.cloud.osconfig_v1.types.WindowsUpdateSettings):
             Windows update settings. Use this override
             the default windows patch rules.
-        pre_step (~.gco_patch_jobs.ExecStep):
+        pre_step (google.cloud.osconfig_v1.types.ExecStep):
             The ``ExecStep`` to run before the patch update.
-        post_step (~.gco_patch_jobs.ExecStep):
+        post_step (google.cloud.osconfig_v1.types.ExecStep):
             The ``ExecStep`` to run after the patch update.
     """
 
@@ -465,26 +412,19 @@ class PatchConfig(proto.Message):
         NEVER = 3
 
     reboot_config = proto.Field(proto.ENUM, number=1, enum=RebootConfig,)
-
     apt = proto.Field(proto.MESSAGE, number=3, message="AptSettings",)
-
     yum = proto.Field(proto.MESSAGE, number=4, message="YumSettings",)
-
     goo = proto.Field(proto.MESSAGE, number=5, message="GooSettings",)
-
     zypper = proto.Field(proto.MESSAGE, number=6, message="ZypperSettings",)
-
     windows_update = proto.Field(
         proto.MESSAGE, number=7, message="WindowsUpdateSettings",
     )
-
     pre_step = proto.Field(proto.MESSAGE, number=8, message="ExecStep",)
-
     post_step = proto.Field(proto.MESSAGE, number=9, message="ExecStep",)
 
 
 class Instance(proto.Message):
-    r"""Namespace for instance state enums."""
+    r"""Namespace for instance state enums.    """
 
     class PatchState(proto.Enum):
         r"""Patch state of an instance."""
@@ -508,14 +448,13 @@ class Instance(proto.Message):
 
 class CancelPatchJobRequest(proto.Message):
     r"""Message for canceling a patch job.
-
     Attributes:
         name (str):
             Required. Name of the patch in the form
             ``projects/*/patchJobs/*``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class AptSettings(proto.Message):
@@ -524,7 +463,7 @@ class AptSettings(proto.Message):
     to control how this is executed.
 
     Attributes:
-        type_ (~.gco_patch_jobs.AptSettings.Type):
+        type_ (google.cloud.osconfig_v1.types.AptSettings.Type):
             By changing the type to DIST, the patching is performed
             using ``apt-get dist-upgrade`` instead.
         excludes (Sequence[str]):
@@ -546,10 +485,8 @@ class AptSettings(proto.Message):
         UPGRADE = 2
 
     type_ = proto.Field(proto.ENUM, number=1, enum=Type,)
-
-    excludes = proto.RepeatedField(proto.STRING, number=2)
-
-    exclusive_packages = proto.RepeatedField(proto.STRING, number=3)
+    excludes = proto.RepeatedField(proto.STRING, number=2,)
+    exclusive_packages = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class YumSettings(proto.Message):
@@ -576,17 +513,14 @@ class YumSettings(proto.Message):
             fields.
     """
 
-    security = proto.Field(proto.BOOL, number=1)
-
-    minimal = proto.Field(proto.BOOL, number=2)
-
-    excludes = proto.RepeatedField(proto.STRING, number=3)
-
-    exclusive_packages = proto.RepeatedField(proto.STRING, number=4)
+    security = proto.Field(proto.BOOL, number=1,)
+    minimal = proto.Field(proto.BOOL, number=2,)
+    excludes = proto.RepeatedField(proto.STRING, number=3,)
+    exclusive_packages = proto.RepeatedField(proto.STRING, number=4,)
 
 
 class GooSettings(proto.Message):
-    r"""Googet patching is performed by running ``googet update``."""
+    r"""Googet patching is performed by running ``googet update``.    """
 
 
 class ZypperSettings(proto.Message):
@@ -615,24 +549,18 @@ class ZypperSettings(proto.Message):
             with any other patch configuration fields.
     """
 
-    with_optional = proto.Field(proto.BOOL, number=1)
-
-    with_update = proto.Field(proto.BOOL, number=2)
-
-    categories = proto.RepeatedField(proto.STRING, number=3)
-
-    severities = proto.RepeatedField(proto.STRING, number=4)
-
-    excludes = proto.RepeatedField(proto.STRING, number=5)
-
-    exclusive_patches = proto.RepeatedField(proto.STRING, number=6)
+    with_optional = proto.Field(proto.BOOL, number=1,)
+    with_update = proto.Field(proto.BOOL, number=2,)
+    categories = proto.RepeatedField(proto.STRING, number=3,)
+    severities = proto.RepeatedField(proto.STRING, number=4,)
+    excludes = proto.RepeatedField(proto.STRING, number=5,)
+    exclusive_patches = proto.RepeatedField(proto.STRING, number=6,)
 
 
 class WindowsUpdateSettings(proto.Message):
     r"""Windows patching is performed using the Windows Update Agent.
-
     Attributes:
-        classifications (Sequence[~.gco_patch_jobs.WindowsUpdateSettings.Classification]):
+        classifications (Sequence[google.cloud.osconfig_v1.types.WindowsUpdateSettings.Classification]):
             Only apply updates of these windows update
             classifications. If empty, all updates are
             applied.
@@ -661,20 +589,17 @@ class WindowsUpdateSettings(proto.Message):
         UPDATE = 9
 
     classifications = proto.RepeatedField(proto.ENUM, number=1, enum=Classification,)
-
-    excludes = proto.RepeatedField(proto.STRING, number=2)
-
-    exclusive_patches = proto.RepeatedField(proto.STRING, number=3)
+    excludes = proto.RepeatedField(proto.STRING, number=2,)
+    exclusive_patches = proto.RepeatedField(proto.STRING, number=3,)
 
 
 class ExecStep(proto.Message):
     r"""A step that runs an executable for a PatchJob.
-
     Attributes:
-        linux_exec_step_config (~.gco_patch_jobs.ExecStepConfig):
+        linux_exec_step_config (google.cloud.osconfig_v1.types.ExecStepConfig):
             The ExecStepConfig for all Linux VMs targeted
             by the PatchJob.
-        windows_exec_step_config (~.gco_patch_jobs.ExecStepConfig):
+        windows_exec_step_config (google.cloud.osconfig_v1.types.ExecStepConfig):
             The ExecStepConfig for all Windows VMs
             targeted by the PatchJob.
     """
@@ -682,7 +607,6 @@ class ExecStep(proto.Message):
     linux_exec_step_config = proto.Field(
         proto.MESSAGE, number=1, message="ExecStepConfig",
     )
-
     windows_exec_step_config = proto.Field(
         proto.MESSAGE, number=2, message="ExecStepConfig",
     )
@@ -690,17 +614,16 @@ class ExecStep(proto.Message):
 
 class ExecStepConfig(proto.Message):
     r"""Common configurations for an ExecStep.
-
     Attributes:
         local_path (str):
             An absolute path to the executable on the VM.
-        gcs_object (~.gco_patch_jobs.GcsObject):
+        gcs_object (google.cloud.osconfig_v1.types.GcsObject):
             A Cloud Storage object containing the
             executable.
         allowed_success_codes (Sequence[int]):
             Defaults to [0]. A list of possible return values that the
             execution can return to indicate a success.
-        interpreter (~.gco_patch_jobs.ExecStepConfig.Interpreter):
+        interpreter (google.cloud.osconfig_v1.types.ExecStepConfig.Interpreter):
             The script interpreter to use to run the script. If no
             interpreter is specified the script will be executed
             directly, which will likely only succeed for scripts with
@@ -714,20 +637,16 @@ class ExecStepConfig(proto.Message):
         SHELL = 1
         POWERSHELL = 2
 
-    local_path = proto.Field(proto.STRING, number=1, oneof="executable")
-
+    local_path = proto.Field(proto.STRING, number=1, oneof="executable",)
     gcs_object = proto.Field(
         proto.MESSAGE, number=2, oneof="executable", message="GcsObject",
     )
-
-    allowed_success_codes = proto.RepeatedField(proto.INT32, number=3)
-
+    allowed_success_codes = proto.RepeatedField(proto.INT32, number=3,)
     interpreter = proto.Field(proto.ENUM, number=4, enum=Interpreter,)
 
 
 class GcsObject(proto.Message):
     r"""Cloud Storage object representation.
-
     Attributes:
         bucket (str):
             Required. Bucket of the Cloud Storage object.
@@ -740,11 +659,9 @@ class GcsObject(proto.Message):
             change.
     """
 
-    bucket = proto.Field(proto.STRING, number=1)
-
-    object_ = proto.Field(proto.STRING, number=2)
-
-    generation_number = proto.Field(proto.INT64, number=3)
+    bucket = proto.Field(proto.STRING, number=1,)
+    object_ = proto.Field(proto.STRING, number=2,)
+    generation_number = proto.Field(proto.INT64, number=3,)
 
 
 class PatchInstanceFilter(proto.Message):
@@ -757,7 +674,7 @@ class PatchInstanceFilter(proto.Message):
         all_ (bool):
             Target all VM instances in the project. If
             true, no other criteria is permitted.
-        group_labels (Sequence[~.gco_patch_jobs.PatchInstanceFilter.GroupLabel]):
+        group_labels (Sequence[google.cloud.osconfig_v1.types.PatchInstanceFilter.GroupLabel]):
             Targets VM instances matching ANY of these
             GroupLabels. This allows targeting of disparate
             groups of VM instances.
@@ -790,23 +707,19 @@ class PatchInstanceFilter(proto.Message):
         and ``app=web``.
 
         Attributes:
-            labels (Sequence[~.gco_patch_jobs.PatchInstanceFilter.GroupLabel.LabelsEntry]):
+            labels (Sequence[google.cloud.osconfig_v1.types.PatchInstanceFilter.GroupLabel.LabelsEntry]):
                 Compute Engine instance labels that must be
                 present for a VM instance to be targeted by this
                 filter.
         """
 
-        labels = proto.MapField(proto.STRING, proto.STRING, number=1)
-
-    all_ = proto.Field(proto.BOOL, number=1)
+        labels = proto.MapField(proto.STRING, proto.STRING, number=1,)
 
+    all_ = proto.Field(proto.BOOL, number=1,)
     group_labels = proto.RepeatedField(proto.MESSAGE, number=2, message=GroupLabel,)
-
-    zones = proto.RepeatedField(proto.STRING, number=3)
-
-    instances = proto.RepeatedField(proto.STRING, number=4)
-
-    instance_name_prefixes = proto.RepeatedField(proto.STRING, number=5)
+    zones = proto.RepeatedField(proto.STRING, number=3,)
+    instances = proto.RepeatedField(proto.STRING, number=4,)
+    instance_name_prefixes = proto.RepeatedField(proto.STRING, number=5,)
 
 
 class PatchRollout(proto.Message):
@@ -815,9 +728,9 @@ class PatchRollout(proto.Message):
     targeted VMs.
 
     Attributes:
-        mode (~.gco_patch_jobs.PatchRollout.Mode):
+        mode (google.cloud.osconfig_v1.types.PatchRollout.Mode):
             Mode of the patch rollout.
-        disruption_budget (~.osconfig_common.FixedOrPercent):
+        disruption_budget (google.cloud.osconfig_v1.types.FixedOrPercent):
             The maximum number (or percentage) of VMs per zone to
             disrupt at any given moment. The number of VMs calculated
             from multiplying the percentage by the total number of VMs
@@ -855,7 +768,6 @@ class PatchRollout(proto.Message):
         CONCURRENT_ZONES = 2
 
     mode = proto.Field(proto.ENUM, number=1, enum=Mode,)
-
     disruption_budget = proto.Field(
         proto.MESSAGE, number=2, message=osconfig_common.FixedOrPercent,
     )
